TrelloZilla
===========

.. image:: https://img.shields.io/pypi/v/trellozilla.svg
        :target: https://pypi.python.org/pypi/trellozilla

.. image:: https://api.travis-ci.com/moisesguimaraes/trellozilla.svg?branch=master
        :target: https://travis-ci.com/moisesguimaraes/trellozilla

.. image:: https://readthedocs.org/projects/trellozilla/badge/?version=latest
        :target: https://trellozilla.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

TrelloZilla contains a small set of boilerplate code to speed up automations
in/between both Bugzilla and Trello.

* Free software: Apache Software License 2.0
* Documentation: https://trellozilla.readthedocs.io.

Features
--------

* Configurable via oslo.config;
* Generates Trello access tokens;
* Builds Trello API objects based on provided config;
* BUilds Bugzilla API objects based on provided config.
